Module interface

Module interface 

public interface for formatting

Functions

format
Format a number to a specific human readable form defined by the format spec pattern. The method takes in a string specifier and a number and returns the string representation of the formatted number.